package agent

import (
	"fmt"
	"testing"

	"gitlab.com/gitlab-org/cluster-integration/gitlab-agent/v17/pkg/agentcfg"
)

func TestParseTrivyK8sWrapperImage(t *testing.T) {
	tests := []struct {
		name           string
		imageConfig    *agentcfg.TrivyK8SWrapperImage
		expectedResult string
	}{
		{
			name:           "Both repository and tag are configured",
			imageConfig:    &agentcfg.TrivyK8SWrapperImage{Repository: "custom-repo", Tag: "1.2.3"},
			expectedResult: "custom-repo:1.2.3",
		},
		{
			name:           "Repository is configured, tag is not configured",
			imageConfig:    &agentcfg.TrivyK8SWrapperImage{Repository: "custom-repo"},
			expectedResult: fmt.Sprintf("custom-repo:%s", defaultTrivyK8sWrapperImageTag),
		},
		{
			name:           "Tag is configured, repository is not configured",
			imageConfig:    &agentcfg.TrivyK8SWrapperImage{Tag: "4.5.6"},
			expectedResult: fmt.Sprintf("%s:4.5.6", defaultTrivyK8sWrapperImageRepository),
		},
		{
			name:           "Both repository and tag are not configured",
			imageConfig:    &agentcfg.TrivyK8SWrapperImage{},
			expectedResult: fmt.Sprintf("%s:%s", defaultTrivyK8sWrapperImageRepository, defaultTrivyK8sWrapperImageTag),
		},
		{
			name:           "TrivyK8SWrapperImage is nil",
			imageConfig:    nil,
			expectedResult: fmt.Sprintf("%s:%s", defaultTrivyK8sWrapperImageRepository, defaultTrivyK8sWrapperImageTag),
		},
	}

	factory := &workerFactory{}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			result := factory.parseTrivyK8sWrapperImage(tt.imageConfig)
			if result != tt.expectedResult {
				t.Errorf("parseTrivyK8sWrapperImage() = %v, want %v", result, tt.expectedResult)
			}
		})
	}
}
